package info.aspirecn.rdc.iov.sjjh.servicenode.supplier.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.commons.lang.PatternTools;
import info.aspirecn.iov.sjjh.service.sms.action.SmsActionInterface;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.constant.ChannelConstant;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.service.WycChannelService;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.utils.DESedeUtil;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.utils.SupplierProperties;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.vo.*;
import lombok.extern.slf4j.Slf4j;
import okhttp3.*;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import java.io.IOException;
import java.net.SocketException;
import java.net.SocketTimeoutException;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.TimeUnit;


/**
 * @author chenqingqing
 * @Description
 */

@Slf4j
@Service
public class WycChannelServiceImpl implements WycChannelService {
   @Autowired
   private ObjectMapper objectMapper;
    @Autowired
    SupplierProperties supplierProperties;
    @Autowired
    SmsActionInterface smsActionInterface;
    private OkHttpClient okHttpClient = new OkHttpClient.Builder().build();
    @Autowired
    StringRedisTemplate stringTemplate;
    @Value("${supplier.decode.api}")
    private String decodeApi;
    @Value("${supplier.decode.url}")
    private String decodeUrl;
    @Value("${supplier.decode.appKey}")
    private String decodeAppKey;
    @Value("${supplier.decode.appSecret}")
    private String decodeAppSecret;
    @Value("${supplier.vehicleFigureUrl}")
    private String vehicleFigureUrl;

    @Override
    public ChannelTypeHandleResponseObject WycInfoRequest(HttpServletRequest request,
                                                                     String channelId, Integer outTime, String customBody) {
        int money = Integer.parseInt(request.getHeader(Constant.ROUTE_PRICE));
        int secondMoney = Integer.parseInt(request.getHeader(Constant.ROUTE_SECOND_PRICE));

        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        ret.setCode(Constant.SUCCESS);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;

        try {
            if(outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("WycInfoRequest---customBody={},outTime={}",customBody,outTime);
            WycInfoRequestObject wycInfoRequestObject = objectMapper.readValue(customBody,
                    WycInfoRequestObject.class);
             if (StringUtils.isBlank(wycInfoRequestObject.getName()) ||
                    !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, wycInfoRequestObject.getName())) {
                 ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                 ret.setResultBody(Constant.INVALID_PARAMETER);
                 ret.setResultDesc(Constant.INVALID_PARAMETER);
                 return ret;
            } else if (StringUtils.isBlank(wycInfoRequestObject.getIdCode())
                    || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, wycInfoRequestObject.getIdCode())) {
                 ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                 ret.setResultBody(Constant.INVALID_PARAMETER);
                 ret.setResultDesc(Constant.INVALID_PARAMETER);
                 return ret;

            }




            // 创建一个请求 Builder
            Request.Builder builder = new Request.Builder();
            Request okRequest = new Request.Builder()
                            .get()
                            .url(supplierProperties.getUrl())
                            .build();
            HttpUrl.Builder urlBuilder = okRequest.url().newBuilder();
            urlBuilder.addQueryParameter("company_id",supplierProperties.getCompany_id());
            urlBuilder.addQueryParameter("dri_name",wycInfoRequestObject.getName());
            urlBuilder.addQueryParameter("idcard",wycInfoRequestObject.getIdCode());
            builder.url(urlBuilder.build());

                    OkHttpClient client = okHttpClient.newBuilder()
                            .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                            .readTimeout(outTime, TimeUnit.MILLISECONDS)
                            .writeTimeout(outTime, TimeUnit.MILLISECONDS)

                            .build();
                    Response response = client.newCall(builder.build()).execute();
                    String responseContext = response.body().string();
            //
            log.info("supplier10000036.WycInfoRequest接口responseContext={}",responseContext);

            WycInfoResponseObject wycInfoResponseObject = objectMapper.readValue(responseContext, WycInfoResponseObject.class);
            if(wycInfoResponseObject !=null){
                upstreamCode = String.valueOf(wycInfoResponseObject.getCode());
                if(wycInfoResponseObject.getCode()==1 && wycInfoResponseObject.getState()==0){//库无
                    ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                    ret.setResultBody("查询成功，查无结果");
                    ret.setResultDesc("查询成功，查无结果");
                }else if(wycInfoResponseObject.getCode()==0 && wycInfoResponseObject.getState()==0){//计费分析
                    ret.setIsCharge(Constant.IS_CHARGE);
                    ret.setResultCode(Constant.MATCH_CODE);
                    String message = wycInfoResponseObject.getMessage();
                    //ret.setResultBody(message);
                    if(secondMoney!=0) {
                        String[] result = message.substring(1, message.length()).substring(0, message.length() - 2).split(",");
                        int index = 0;
                        for (; index < result.length; index++) {
                            String[] details = result[index].split("=");
                            if (!"workTimeLevel".equals(details[0]) && !"'A'".equals(details[1])) {
                                break;
                            }
                        }
                        if (index >= result.length) {
                            money = secondMoney;
                            String channel_second_price = (String) request.getHeader(Constant.CHANNEL_SECOND_PRICE);
                            request.setAttribute(Constant.CHANNEL_PRICE, channel_second_price);
                        }

                    }
                    Map<String,String> mapResult = new HashMap<String,String>();
                    String[] result = message.substring(1, message.length()).substring(0, message.length() - 2).split(",");
                    for (int index = 0; index < result.length; index++) {
                        String[] details = result[index].split("=");
                        mapResult.put(details[0],details[1]);
                    }
                    String resultBody = objectMapper.writeValueAsString(mapResult);
                    resultBody = resultBody.replace("'","");
                    ret.setResultBody(resultBody);
                     ret.setJfFree(money);
                   ret.setJflx(3);
                    ret.setResultDesc("查询成功，查有结果");
                }else{//其他
                    ret.setResultCode(Constant.OTHER_ERROR_CODE);
                    ret.setResultBody("查询错误");
                    ret.setResultDesc("查询错误");
                }
            }else{
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody("查询错误");
                ret.setResultDesc("查询错误");
            }
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE,  upstreamCode);


        } catch(SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000036.WycInfoRequest接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch(Exception e) {
            ErrorUtils.captureException(e);
            log.info("supplier10000036.WycInfoRequest接口Exception={}", e);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }
    @Override
    public ChannelTypeHandleResponseObject onlineCarHailingQuery(HttpServletRequest request, Integer outTime, String customBody) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);

        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= 0) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }

        log.info("onlineCarHailingQuery---customBody={},outTime={}", customBody, outTime);

        try {
            OnlineDriverHailingRequestObject jsonResolveObject = objectMapper.readValue(customBody,
                    OnlineDriverHailingRequestObject.class);
            // 参数校验
            if (!validateRequestParams(ret, returnType, jsonResolveObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            Request.Builder builder = new Request.Builder();
            Request okRequest = new Request.Builder()
                    .get()
                    .url(supplierProperties.getUrl())
                    .build();
            HttpUrl.Builder urlBuilder = okRequest.url().newBuilder();
            urlBuilder.addQueryParameter("company_id",supplierProperties.getCompany_id());
            urlBuilder.addQueryParameter("dri_name",jsonResolveObject.getName());
            urlBuilder.addQueryParameter("idcard",jsonResolveObject.getIdCode());
            builder.url(urlBuilder.build());

            OkHttpClient client = okHttpClient.newBuilder()
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)

                    .build();
            Response response = client.newCall(builder.build()).execute();
            String responseContext = response.body().string();
            log.info("supplier10000036.onlineCarHailingQuery接口responseContext={}",responseContext);

            WycInfoResponseObject responseObject = objectMapper.readValue(responseContext, WycInfoResponseObject.class);

            if (responseObject != null) {
                ret.setCode(Constant.SUCCESS);
                setOnlineCarHailingResponse(ret, returnType, responseObject, jsonResolveObject);
                upstreamCode = responseObject.getCode() + "," + responseObject.getState();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000036.onlineCarHailingQuery接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000036.onlineCarHailingQuery接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }
        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private void setOnlineCarHailingResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                             WycInfoResponseObject responseObject,
                                             OnlineDriverHailingRequestObject requestObject) {
        int code = responseObject.getCode();
        int state = responseObject.getState();
        String message = responseObject.getMessage();
        boolean isCharge = responseObject != null
                && code == 0
                && state == 0;
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }

        if (code == 0 && state == 0 && StringUtils.isNotBlank(message)) {
            // 查询成功，返回结果
            // 解析返回结果
            String[] results =  message.substring(1).substring(0,message.length()-2).replace("'", "").split(",");
            Map<String, String> messageMap = new HashMap<>();
            for (String r : results) {
                String[] arr = r.split("=");
                messageMap.put(arr[0], arr[1]);
            }
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("workTimeLevel", messageMap.get("workTimeLevel"));
            jsonObject.put("incomeLevel", messageMap.get("incomeLevel" + requestObject.getMonth()));
            jsonObject.put("orderLevel", messageMap.get("orderLevel" + requestObject.getMonth()));

            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
            ret.setResultBody(JSON.toJSONString(jsonObject));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
        } else if (code == 1 && state == 0) {
            // 库无
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(ChannelConstant.NO_RESULT);
            ret.setResultDesc(ChannelConstant.NO_RESULT);
        } else {
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    private boolean validateParamNullValue(Object jsonResolveObject) {
        ValidatorFactory vf = Validation.buildDefaultValidatorFactory();
        Validator validator = vf.getValidator();
        Set<ConstraintViolation<Object>> set = validator.validate(jsonResolveObject);
        for (ConstraintViolation<Object> con : set) {
            if (StringUtils.isNotBlank(con.getMessage())) {
                return false;
            }
        }
        return true;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          OnlineDriverHailingRequestObject jsonResolveObject) {
        if (!validateParamNullValue(jsonResolveObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(jsonResolveObject.getName()) ||
                !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, jsonResolveObject.getName())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
                ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
                ret.setResultBody(Constant.NAME_FORMAT_ERROR);
            } else {
                ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
                ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
                ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(jsonResolveObject.getIdCode())
                || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, jsonResolveObject.getIdCode())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
                ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
                ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
            } else {
                ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
                ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
                ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(jsonResolveObject.getMonth())
                || !ArrayUtils.contains(ChannelConstant.MONTH_ARRAY, jsonResolveObject.getMonth())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            }
            return false;
        }
        return true;
    }
    //每一分执行一下定时任务

    @Scheduled(cron = "${vpn.heartbeat}")
    public void refresh(){
        //查询这个时间减去当前时间小于25分钟，
        try {
            log.info("----------------");
            if (supplierProperties.isSign()) {
                long currentTime = System.currentTimeMillis();
                String timeStr = stringTemplate.boundValueOps("wyc_refre").get();
                boolean flag = false;
                if (timeStr == null) {
                    flag = true;
                } else {
                    long interval = currentTime - Long.parseLong(timeStr);
                    if (interval > supplierProperties.getInterval()) {//大于25分钟
                        flag = true;
                    }
                }
                log.info("flag:{}", flag);
                if (flag) {
                    // 创建一个请求 Builder
                    Request.Builder builder = new Request.Builder();
                    Request okRequest = new Request.Builder()
                            .get()
                            .url(supplierProperties.getUrl())
                            .build();
                    HttpUrl.Builder urlBuilder = okRequest.url().newBuilder();
                    urlBuilder.addQueryParameter("company_id", supplierProperties.getCompany_id());
                    urlBuilder.addQueryParameter("dri_name", "111");
                    urlBuilder.addQueryParameter("idcard", "111");
                    builder.url(urlBuilder.build());

                    OkHttpClient client = okHttpClient.newBuilder()
                            .connectTimeout(10000, TimeUnit.MILLISECONDS)
                            .readTimeout(10000, TimeUnit.MILLISECONDS)
                            .writeTimeout(10000, TimeUnit.MILLISECONDS)

                            .build();


                    Response response = client.newCall(builder.build()).execute();
                    String responseContext = response.body().string();

                    log.info("responseContext:{}", responseContext);
                    /*if(!"{\"code\":1,\"message\":\"库无\",\"state\":0}".equals(responseContext)&&supplierProperties.getFlag()==1){
                        RequestSmsObject requestSms = new RequestSmsObject();
                        requestSms.setTargetMobile("18210953442");
                        requestSms.setParams(new Object[]{"网约车vpn连接失败，请重新启动vpn"});
                        requestSms.setTempleteId(1);
                        try {
                            smsActionInterface.smsSend(requestSms);
                        } catch (IOException e) {
                            log.error("exception:{}", e);
                        }
                    }*/


                    stringTemplate.boundValueOps("wyc_refre").set(String.valueOf(currentTime));



                }
            }
        } catch(IOException e){
                log.error("exception:{}", e);
        }

    }

    @Override
    public ChannelTypeHandleResponseObject encryptOnlineCarHailingQuery(HttpServletRequest request, Integer outTime, String customBody) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);

        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= 0) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }

        log.info("onlineCarHailingQuery---customBody={},outTime={}", customBody, outTime);

        try {
            // 参数校验
            if (!validateEncryptRequestParams(ret, returnType, customBody)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }
            JSONObject requestParamObject = JSONObject.parseObject(customBody);
            OnlineDriverHailingRequestObject jsonResolveObject = objectMapper.readValue(DESedeUtil.decryptMode(requestParamObject.get("params").toString(), supplierProperties.getDecryptKey()),
                    OnlineDriverHailingRequestObject.class);

            // 参数校验
            if (!validateRequestParams(ret, returnType, jsonResolveObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            Request.Builder builder = new Request.Builder();
            Request okRequest = new Request.Builder()
                    .get()
                    .url(supplierProperties.getUrl())
                    .build();
            HttpUrl.Builder urlBuilder = okRequest.url().newBuilder();
            urlBuilder.addQueryParameter("company_id",supplierProperties.getCompany_id());
            urlBuilder.addQueryParameter("dri_name",jsonResolveObject.getName());
            urlBuilder.addQueryParameter("idcard",jsonResolveObject.getIdCode());
            builder.url(urlBuilder.build());

            OkHttpClient client = okHttpClient.newBuilder()
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)

                    .build();
            Response response = client.newCall(builder.build()).execute();
            String responseContext = response.body().string();
            log.info("supplier10000036.onlineCarHailingQuery接口responseContext={}",responseContext);

            WycInfoResponseObject responseObject = objectMapper.readValue(responseContext, WycInfoResponseObject.class);

            if (responseObject != null) {
                ret.setCode(Constant.SUCCESS);
                setOnlineCarHailingResponse(ret, returnType, responseObject, jsonResolveObject);
                upstreamCode = responseObject.getCode() + "," + responseObject.getState();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000036.encryptOnlineCarHailingQuery接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000036.encryptOnlineCarHailingQuery接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }
        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateEncryptRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          String customBody) {
        JSONObject requestParamObject = JSONObject.parseObject(customBody);
        if (requestParamObject.get("params") == null) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
            }
            return false;
        }
        String requestParam = DESedeUtil.decryptMode(requestParamObject.get("params").toString(), supplierProperties.getDecryptKey());
        if (StringUtils.isBlank(requestParam)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.ZW_RETURN_CODE_133);
                ret.setResultBody(Constant.RETURN_MESSAGE_133);
                ret.setResultDesc(Constant.RETURN_MESSAGE_133);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_9931);
                ret.setResultBody(Constant.RETURN_MESSAGE_133);
                ret.setResultDesc(Constant.RETURN_MESSAGE_133);
            }
            return false;
        }
        return true;
    }

    @Override
    public ChannelTypeHandleResponseObject WycInfoDecodeRequest(HttpServletRequest request, String channelId,
                                                                Integer outTime, String customBody, String encryptType) {
        int money = Integer.parseInt(request.getHeader(Constant.ROUTE_PRICE));
        int secondMoney = Integer.parseInt(request.getHeader(Constant.ROUTE_SECOND_PRICE));
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        ret.setCode(Constant.SUCCESS);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;

        try {
            if(outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("WycInfoDecodeRequest---customBody={},outTime={}",customBody,outTime);

            WycInfoRequestObject wycInfoRequestObject = objectMapper.readValue(customBody,
                    WycInfoRequestObject.class);

            if (wycInfoRequestObject.getIdCode().equals("5cb210e94190a6879e675bd41576f45b")
                    && wycInfoRequestObject.getName().equals("杨辛")) {
                String resultBody = "{\"orderLevel3\":\"B\",\"workTimeLevel\":\"A\",\"orderLevel12\":\"B\",\"incomeLevel1\":\"D\",\"orderLevel1\":\"B\",\"incomeLevel3\":\"C\",\"incomeLevel6\":\"E\",\"incomeLevel12\":\"E\",\"orderLevel6\":\"B\"}";
                ret.setResultBody(resultBody);
                ret.setIsCharge(Constant.IS_NOT_CHARGE);
                ret.setResultCode(Constant.MATCH_CODE);
                ret.setResultDesc("查询成功，查有结果");
                log.info("supplier10000036.WycInfoDecodeRequest接口挡板数据");
                return ret;
            }
            if (wycInfoRequestObject.getIdCode().equals("a91783137a8a831ddd299d1bfa6a7836")
                    && wycInfoRequestObject.getName().equals("苏东")) {
                ret.setResultBody("查询成功，查无结果");
                ret.setIsCharge(Constant.IS_NOT_CHARGE);
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                ret.setResultDesc("查询成功，查无结果");
                log.info("supplier10000036.WycInfoDecodeRequest接口挡板数据");
                return ret;
            }
            if (wycInfoRequestObject.getIdCode().equals("54177ca119be792945b7c6df8c2b2ca2295bacfa864819dc8e2e296df4a7662c")
                    && wycInfoRequestObject.getName().equals("王钢")) {
                String resultBody = "{\"orderLevel3\":\"C\",\"workTimeLevel\":\"A\",\"orderLevel12\":\"D\",\"incomeLevel1\":\"E\",\"orderLevel1\":\"E\",\"incomeLevel3\":\"E\",\"incomeLevel6\":\"E\",\"incomeLevel12\":\"E\",\"orderLevel6\":\"D\"}";
                ret.setResultBody(resultBody);
                ret.setIsCharge(Constant.IS_NOT_CHARGE);
                ret.setResultCode(Constant.MATCH_CODE);
                ret.setResultDesc("查询成功，查有结果");
                log.info("supplier10000036.WycInfoDecodeRequest接口挡板数据");
                return ret;
            }
            if (wycInfoRequestObject.getIdCode().equals("4c2c035749cb2032125e3462e36d269498aaf407bcd386d1395c0746d3ca8814")
                    && wycInfoRequestObject.getName().equals("方王斌")) {
                ret.setResultBody("查询成功，查无结果");
                ret.setIsCharge(Constant.IS_NOT_CHARGE);
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                ret.setResultDesc("查询成功，查无结果");
                log.info("supplier10000036.WycInfoDecodeRequest接口挡板数据");
                return ret;
            }

            String idCode = getDecodeIdCode(wycInfoRequestObject.getIdCode(), outTime, encryptType);
            if (idCode == null || idCode.equals("")) {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody(Constant.OTHER_ERROR);
                ret.setResultDesc(Constant.OTHER_ERROR);
                return ret;
            }

            if (StringUtils.isBlank(wycInfoRequestObject.getName()) ||
                    !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, wycInfoRequestObject.getName())) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
                return ret;
            } else if (StringUtils.isBlank(idCode)
                    || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, idCode)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                ret.setResultDesc(Constant.INVALID_PARAMETER);
                return ret;

            }

            // 创建一个请求 Builder
            Request.Builder builder = new Request.Builder();
            Request okRequest = new Request.Builder()
                    .get()
                    .url(supplierProperties.getUrl())
                    .build();
            HttpUrl.Builder urlBuilder = okRequest.url().newBuilder();
            urlBuilder.addQueryParameter("company_id",supplierProperties.getCompany_id());
            urlBuilder.addQueryParameter("dri_name",wycInfoRequestObject.getName());
            urlBuilder.addQueryParameter("idcard",idCode);
            builder.url(urlBuilder.build());

            OkHttpClient client = okHttpClient.newBuilder()
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)

                    .build();
            Response response = client.newCall(builder.build()).execute();
            String responseContext = response.body().string();
            //
            log.info("supplier10000036.WycInfoDecodeRequest接口responseContext={}",responseContext);

            WycInfoResponseObject wycInfoResponseObject = objectMapper.readValue(responseContext, WycInfoResponseObject.class);
            if(wycInfoResponseObject !=null){
                upstreamCode = String.valueOf(wycInfoResponseObject.getCode());
                if(wycInfoResponseObject.getCode()==1 && wycInfoResponseObject.getState()==0){//库无
                    ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                    ret.setResultBody("查询成功，查无结果");
                    ret.setResultDesc("查询成功，查无结果");
                }else if(wycInfoResponseObject.getCode()==0 && wycInfoResponseObject.getState()==0){//计费分析
                    ret.setIsCharge(Constant.IS_CHARGE);
                    ret.setResultCode(Constant.MATCH_CODE);
                    String message = wycInfoResponseObject.getMessage();
                    //ret.setResultBody(message);
                    if(secondMoney!=0) {
                        String[] result = message.substring(1, message.length()).substring(0, message.length() - 2).split(",");
                        int index = 0;
                        for (; index < result.length; index++) {
                            String[] details = result[index].split("=");
                            if (!"workTimeLevel".equals(details[0]) && !"'A'".equals(details[1])) {
                                break;
                            }
                        }
                        if (index >= result.length) {
                            money = secondMoney;
                            String channel_second_price = (String) request.getHeader(Constant.CHANNEL_SECOND_PRICE);
                            request.setAttribute(Constant.CHANNEL_PRICE, channel_second_price);
                        }

                    }
                    Map<String,String> mapResult = new HashMap<String,String>();
                    String[] result = message.substring(1, message.length()).substring(0, message.length() - 2).split(",");
                    for (int index = 0; index < result.length; index++) {
                        String[] details = result[index].split("=");
                        mapResult.put(details[0],details[1]);
                    }
                    String resultBody = objectMapper.writeValueAsString(mapResult);
                    resultBody = resultBody.replace("'","");
                    ret.setResultBody(resultBody);
                    ret.setJfFree(money);
                    ret.setJflx(3);
                    ret.setResultDesc("查询成功，查有结果");
                }else{//其他
                    ret.setResultCode(Constant.OTHER_ERROR_CODE);
                    ret.setResultBody("查询错误");
                    ret.setResultDesc("查询错误");
                }
            }else{
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody("查询错误");
                ret.setResultDesc("查询错误");
            }
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE,  upstreamCode);


        } catch(SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000036.WycInfoDecodeRequest接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch(Exception e) {
            ErrorUtils.captureException(e);
            log.info("supplier10000036.WycInfoDecodeRequest接口Exception={}", e);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private String getDecodeIdCode(String encodeIdCode, Integer outTime, String encryptType) {
        DecodeThreeElementRequestObject.DecodeThreeElementRequestData dataObject = new DecodeThreeElementRequestObject.DecodeThreeElementRequestData();
        dataObject.setId_number(encodeIdCode);
        dataObject.setEncrypt(encryptType);
        DecodeThreeElementRequestObject requestObject = new DecodeThreeElementRequestObject();
        requestObject.setApi(decodeApi);
        requestObject.setAppKey(decodeAppKey);
        requestObject.setAppSecret(decodeAppSecret);
        requestObject.setData(dataObject);

        MediaType mediaType = MediaType.parse("application/json; charset=utf-8");
        RequestBody requestBody = RequestBody.create(mediaType, JSON.toJSONString(requestObject));
        Request okHttpRequest = new Request.Builder()
                .post(requestBody)
                .url(decodeUrl)
                .build();
        OkHttpClient decodeClient = new OkHttpClient.Builder()
                .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                .readTimeout(outTime, TimeUnit.MILLISECONDS)
                .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                .build();
        try {
            Response decodeResponse = decodeClient.newCall(okHttpRequest).execute();
            String decodeResponseContext = "";
            if (decodeResponse.body() != null) {
                decodeResponseContext = decodeResponse.body().string();
            }
            log.info("supplier10000036.scmDecodeIdCode接口decodeResponseContext={}", decodeResponseContext);
            JSONObject decodeResponseObject = JSON.parseObject(decodeResponseContext);
            if (decodeResponseObject != null && decodeResponseObject.getString("code").equals("200") && decodeResponseObject.getString("data").equals("1")) {
                JSONObject msg = JSON.parseObject(JSON.toJSONString(decodeResponseObject.get("msg")));
                return msg.getString("idcard");
            } else {
                return null;
            }
        } catch (Exception e) {
            ErrorUtils.captureException(e);
            log.info("supplier10000036.decodeIdCode接口SocketTimeoutException={}", e);
            return null;
        }
    }

    @Override
    public ChannelTypeHandleResponseObject vehicleInfoQuery(HttpServletRequest request, String channelId, Integer outTime, String customBody) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);

        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= 0) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }

        log.info("vehicleInfoQuery---customBody={},outTime={}", customBody, outTime);

        try {
            VehicleInfoQueryRequestObject jsonResolveObject = objectMapper.readValue(customBody,
                    VehicleInfoQueryRequestObject.class);
            // 参数校验
            if (!validateRequestParams(ret, returnType, jsonResolveObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            Request.Builder builder = new Request.Builder();
            Request okRequest = new Request.Builder()
                    .get()
                    .url(vehicleFigureUrl)
                    .build();
            HttpUrl.Builder urlBuilder = okRequest.url().newBuilder();
            urlBuilder.addQueryParameter("company_id",supplierProperties.getCompany_id());
            urlBuilder.addQueryParameter("veh_no",jsonResolveObject.getPlateNum());
            builder.url(urlBuilder.build());

            OkHttpClient client = okHttpClient.newBuilder()
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)

                    .build();
            Response response = client.newCall(builder.build()).execute();
            String responseContext = response.body().string();
            log.info("supplier10000036.vehicleInfoQuery接口responseContext={}",responseContext);
            WycInfoResponseObject responseObject = objectMapper.readValue(responseContext, WycInfoResponseObject.class);

            if (responseObject != null) {
                ret.setCode(Constant.SUCCESS);
                setVehicleInfoQueryResponse(ret, returnType, responseObject, request);
                upstreamCode = responseObject.getCode() + "," + responseObject.getState();
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000036.vehicleInfoQuery接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (SocketException se) {
            ErrorUtils.captureException(se);
            log.info("supplier10000036.vehicleInfoQuery接口SocketException={}", se);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            ErrorUtils.captureException(ioe);
            log.info("supplier10000036.vehicleInfoQuery接口Exception={}", ioe);
            ret.setCode(Constant.FAIL);
        }
        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          VehicleInfoQueryRequestObject jsonResolveObject) {
        if (!validateParamNullValue(jsonResolveObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return false;
        } else if (StringUtils.isBlank(jsonResolveObject.getPlateNum()) ||
                !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, jsonResolveObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    private void setVehicleInfoQueryResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                             WycInfoResponseObject responseObject, HttpServletRequest request) {
        int code = responseObject.getCode();
        int state = responseObject.getState();
        int chargeMoney = 0;

        if(responseObject != null){
            if(code == 1 && state == 0){//库无
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                ret.setResultBody("查询成功，查无结果");
                ret.setResultDesc("查询成功，查无结果");

                chargeMoney = Integer.parseInt(request.getHeader(Constant.ROUTE_SECOND_PRICE));
                ret.setIsCharge(Constant.IS_CHARGE);
            }else if(code == 0 && state == 0){//计费分析
                String message = responseObject.getMessage();
                Map<String,String> mapResult = new HashMap<String,String>();
                String[] result = message.substring(12, message.length()).substring(0, message.length() - 13).split(",");
                for (int index = 0; index < result.length; index++) {
                    String[] details = result[index].split("=");
                    mapResult.put(details[0],details[1]);
                }
                String resultBody = JSON.toJSONString(mapResult);
                resultBody = resultBody.replace("'","");

                chargeMoney = Integer.parseInt(request.getHeader(Constant.ROUTE_PRICE));
                ret.setIsCharge(Constant.IS_CHARGE);
                ret.setResultCode(Constant.MATCH_CODE);
                ret.setResultBody(resultBody);
                ret.setResultDesc("查询成功，查有结果");
            }else{//其他
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody("查询错误");
                ret.setResultDesc("查询错误");
            }
        }else{
            ret.setResultCode(Constant.OTHER_ERROR_CODE);
            ret.setResultBody("查询错误");
            ret.setResultDesc("查询错误");
        }

        if (ret.getIsCharge() == Constant.IS_CHARGE) {
            ret.setJfFree(chargeMoney);
            ret.setJflx(3);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject WycInfoDecodeRequestV2(HttpServletRequest request, String channelId,
                                                                Integer outTime, String customBody, String encryptType) {
        int money = Integer.parseInt(request.getHeader(Constant.ROUTE_PRICE));
        int secondMoney = Integer.parseInt(request.getHeader(Constant.ROUTE_SECOND_PRICE));

        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        ret.setCode(Constant.SUCCESS);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;

        try {
            if(outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("WycInfoDecodeRequestV2---customBody={},outTime={}",customBody,outTime);

            WycInfoRequestObject wycInfoRequestObject = objectMapper.readValue(customBody,
                    WycInfoRequestObject.class);
            if (!validateRequestParams(ret, wycInfoRequestObject, encryptType)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            String decodeJSONString = getDecodeIdCodeV2(wycInfoRequestObject.getIdCode(), wycInfoRequestObject.getName(), outTime, encryptType);
            JSONObject jsonObject = JSON.parseObject(decodeJSONString);
            String idCode = jsonObject.getString("idcard");
            String name = jsonObject.getString("name");
            if (idCode == null || idCode.equals("") || name == null || name.equals("")) {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody(Constant.OTHER_ERROR);
                ret.setResultDesc(Constant.OTHER_ERROR);
                return ret;
            }

            // 创建一个请求 Builder
            Request.Builder builder = new Request.Builder();
            Request okRequest = new Request.Builder()
                    .get()
                    .url(supplierProperties.getUrl())
                    .build();
            HttpUrl.Builder urlBuilder = okRequest.url().newBuilder();
            urlBuilder.addQueryParameter("company_id",supplierProperties.getCompany_id());
            urlBuilder.addQueryParameter("dri_name", name);
            urlBuilder.addQueryParameter("idcard",idCode);
            builder.url(urlBuilder.build());

            OkHttpClient client = okHttpClient.newBuilder()
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)

                    .build();
            Response response = client.newCall(builder.build()).execute();
            String responseContext = response.body().string();
            //
            log.info("supplier10000036.WycInfoDecodeRequestV2接口responseContext={}",responseContext);

            WycInfoResponseObject wycInfoResponseObject = objectMapper.readValue(responseContext, WycInfoResponseObject.class);
            if(wycInfoResponseObject !=null){
                upstreamCode = String.valueOf(wycInfoResponseObject.getCode());
                if(wycInfoResponseObject.getCode()==1 && wycInfoResponseObject.getState()==0){//库无
                    ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                    ret.setResultBody("查询成功，查无结果");
                    ret.setResultDesc("查询成功，查无结果");
                }else if(wycInfoResponseObject.getCode()==0 && wycInfoResponseObject.getState()==0){//计费分析
                    ret.setIsCharge(Constant.IS_CHARGE);
                    ret.setResultCode(Constant.MATCH_CODE);
                    String message = wycInfoResponseObject.getMessage();
                    //ret.setResultBody(message);
                    if(secondMoney!=0) {
                        String[] result = message.substring(1, message.length()).substring(0, message.length() - 2).split(",");
                        int index = 0;
                        for (; index < result.length; index++) {
                            String[] details = result[index].split("=");
                            if (!"workTimeLevel".equals(details[0]) && !"'A'".equals(details[1])) {
                                break;
                            }
                        }
                        if (index >= result.length) {
                            money = secondMoney;
                            String channel_second_price = (String) request.getHeader(Constant.CHANNEL_SECOND_PRICE);
                            request.setAttribute(Constant.CHANNEL_PRICE, channel_second_price);
                        }

                    }
                    Map<String,String> mapResult = new HashMap<String,String>();
                    String[] result = message.substring(1, message.length()).substring(0, message.length() - 2).split(",");
                    for (int index = 0; index < result.length; index++) {
                        String[] details = result[index].split("=");
                        mapResult.put(details[0],details[1]);
                    }
                    String resultBody = objectMapper.writeValueAsString(mapResult);
                    resultBody = resultBody.replace("'","");
                    ret.setResultBody(resultBody);
                    ret.setJfFree(money);
                    ret.setJflx(3);
                    ret.setResultDesc("查询成功，查有结果");
                }else{//其他
                    ret.setResultCode(Constant.OTHER_ERROR_CODE);
                    ret.setResultBody("查询错误");
                    ret.setResultDesc("查询错误");
                }
            }else{
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
                ret.setResultBody("查询错误");
                ret.setResultDesc("查询错误");
            }
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE,  upstreamCode);


        } catch(SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            log.info("supplier10000036.WycInfoDecodeRequestV2接口SocketTimeoutException={}", ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch(Exception e) {
            ErrorUtils.captureException(e);
            log.info("supplier10000036.WycInfoDecodeRequestV2接口Exception={}", e);
            ret.setCode(Constant.FAIL);
        }

        //上游返回码
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private String getDecodeIdCodeV2(String encodeIdCode, String name, Integer outTime, String encryptType) {
        DecodeThreeElementRequestObject.DecodeThreeElementRequestData dataObject = new DecodeThreeElementRequestObject.DecodeThreeElementRequestData();
        dataObject.setId_number(encodeIdCode);
        dataObject.setName(name);
        dataObject.setEncrypt(encryptType);
        DecodeThreeElementRequestObject requestObject = new DecodeThreeElementRequestObject();
        requestObject.setApi(decodeApi);
        requestObject.setAppKey(decodeAppKey);
        requestObject.setAppSecret(decodeAppSecret);
        requestObject.setData(dataObject);

        MediaType mediaType = MediaType.parse("application/json; charset=utf-8");
        RequestBody requestBody = RequestBody.create(mediaType, JSON.toJSONString(requestObject));
        Request okHttpRequest = new Request.Builder()
                .post(requestBody)
                .url(decodeUrl)
                .build();
        OkHttpClient decodeClient = new OkHttpClient.Builder()
                .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                .readTimeout(outTime, TimeUnit.MILLISECONDS)
                .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                .build();
        try {
            Response decodeResponse = decodeClient.newCall(okHttpRequest).execute();
            String decodeResponseContext = "";
            if (decodeResponse.body() != null) {
                decodeResponseContext = decodeResponse.body().string();
            }
            log.info("supplier10000036.getDecodeIdCodeV2接口decodeResponseContext={}", decodeResponseContext);
            JSONObject decodeResponseObject = JSON.parseObject(decodeResponseContext);
            if (decodeResponseObject != null && decodeResponseObject.getString("code").equals("200") && decodeResponseObject.getString("data").equals("1")) {
                return JSON.toJSONString(decodeResponseObject.get("msg"));
            } else {
                return null;
            }
        } catch (Exception e) {
            ErrorUtils.captureException(e);
            log.info("supplier10000036.getDecodeIdCodeV2接口SocketTimeoutException={}", e);
            return null;
        }
    }

    private boolean validateRequestParams
            (ChannelTypeHandleResponseObject ret, WycInfoRequestObject wycInfoRequestObject, String encryptType) {
        if (wycInfoRequestObject.getIdCode() == null || wycInfoRequestObject.getName() == null) {
            ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return false;
        } else if (StringUtils.isBlank(wycInfoRequestObject.getIdCode())
                || StringUtils.isBlank(wycInfoRequestObject.getName())) {
            ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (encryptType.equals("MD5")
                && (wycInfoRequestObject.getIdCode().length() != 32
                    || wycInfoRequestObject.getName().length() !=32)) {
            ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else if (encryptType.equals("SHA256")
                && (wycInfoRequestObject.getIdCode().length() != 64
                || wycInfoRequestObject.getName().length() != 64)) {
            ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    @Override
    public ChannelTypeHandleResponseObject vehicleInfoQueryV2(HttpServletRequest request, String channelId, Integer outTime, String customBody) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);

        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= 0) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }

        log.info("vehicleInfoQueryV2---customBody={},outTime={}", customBody, outTime);
        VehicleInfoQueryV2RequestObject jsonResolveObject = new VehicleInfoQueryV2RequestObject();

        try {
            jsonResolveObject = objectMapper.readValue(customBody,
                    VehicleInfoQueryV2RequestObject.class);
        } catch (JsonProcessingException ex) {
            ErrorUtils.captureException(ex);
            log.info("supplier10000036.vehicleInfoQueryV2接口Exception={}", ex);
            ret.setCode(Constant.FAIL);
        }
        // 参数校验
        if (!validateRequestParams(ret, returnType, jsonResolveObject)
                || !validateVehicleInfoRequestParams(ret, returnType, jsonResolveObject)) {
            ret.setCode(Constant.SUCCESS);
            request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
            return ret;
        }
        ret = vehicleInfoQuery(request, channelId, outTime, customBody);
        if (ret.getResultCode() == Constant.MATCH_CODE) {
            JSONObject resultBody = JSON.parseObject((String) ret.getResultBody());
            VehicleInfoQueryV2ResponseObject responseObject = new VehicleInfoQueryV2ResponseObject();
            responseObject.setEarliestOrderMonth(resultBody.getString("earliestOrderMonth"));
            responseObject.setTotalMile(resultBody.getString("totalMile"));
            responseObject.setHalfYearMile(resultBody.getString("mile6"));
            ret.setResultBody(responseObject);
        }
        //上游返回码
        return ret;
    }

    private boolean validateVehicleInfoRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          VehicleInfoQueryV2RequestObject jsonResolveObject) {
        if (StringUtils.isBlank(jsonResolveObject.getVin())
                || StringUtils.isBlank(jsonResolveObject.getBusinessType())
                || StringUtils.isBlank(jsonResolveObject.getCompanyName())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }
}
